@@ -1,12 +1,12 @@
 import os
 import sys
 from argparse import ArgumentParser
-from dataclasses import fields
+from dataclasses import dataclass, fields
 from typing import Tuple
 
 import pytest
 
-from pytoolconfig import PyToolConfig, UniversalKey, dataclass, field
+from pytoolconfig import PyToolConfig, UniversalKey, field
 from pytoolconfig.sources import IniConfig
 from pytoolconfig.universal_config import UniversalConfig
 
@@ -28,7 +28,7 @@ class SubTool:
 
 @dataclass
 class NestedModel:
-    subtool: SubTool = SubTool()
+    subtool: SubTool = field(default_factory=lambda: SubTool())
     foo_other: str = field(description="w", default="no", command_line=("--foo", "-f"))
 
     target: Tuple[int, int] = field(
